@@ -32,7 +32,7 @@ class ShadowstepException(WebDriverException):
             message = self._construct_message_from_context()
         super().__init__(message)
 
-    def _construct_message_from_context(self, **context_kwargs: Any) -> str:
+    def _construct_message_from_context(self, **context_kwargs: Any) -> str:  # noqa: ARG002
         """Construct message from context kwargs."""
         # This method should be overridden by subclasses to provide specific message construction
         return self.default_message
@@ -113,7 +113,7 @@ class ShadowstepTimeoutException(ShadowstepException):
         base = super().__str__()
         if self.locator:
             base += f"\nLocator: {self.locator}"
-        if self.driver and hasattr(self.driver, 'current_url'):
+        if self.driver and hasattr(self.driver, "current_url"):
             base += f"\nCurrent URL: {self.driver.current_url}"
         if self.stacktrace and len(self.stacktrace) > 0:
             base += f"\nStacktrace: {''.join(self.stacktrace)}"
@@ -151,8 +151,8 @@ class ShadowstepDictConversionError(ShadowstepConversionError):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        operation = context_kwargs.get('operation', 'conversion')
-        details = context_kwargs.get('details', 'unknown error')
+        operation = context_kwargs.get("operation", "conversion")
+        details = context_kwargs.get("details", "unknown error")
         return f"Failed to convert dict to {operation}: {details}"
 
 
@@ -167,7 +167,7 @@ class ShadowstepSelectorTypeError(ShadowstepValidationError):
 
     default_message = "ShadowstepSelectorTypeError occurred"
 
-    def _construct_message_from_context(self, **context_kwargs: Any) -> str:
+    def _construct_message_from_context(self, **context_kwargs: Any) -> str:  # noqa: ARG002
         """Construct message from context kwargs."""
         return "Selector must be a dictionary"
 
@@ -177,7 +177,7 @@ class ShadowstepEmptySelectorError(ShadowstepValidationError):
 
     default_message = "ShadowstepEmptySelectorError occurred"
 
-    def _construct_message_from_context(self, **context_kwargs: Any) -> str:
+    def _construct_message_from_context(self, **context_kwargs: Any) -> str:  # noqa: ARG002
         """Construct message from context kwargs."""
         return "Selector dictionary cannot be empty"
 
@@ -187,7 +187,7 @@ class ShadowstepConflictingTextAttributesError(ShadowstepValidationError):
 
     default_message = "ShadowstepConflictingTextAttributesError occurred"
 
-    def _construct_message_from_context(self, **context_kwargs: Any) -> str:
+    def _construct_message_from_context(self, **context_kwargs: Any) -> str:  # noqa: ARG002
         """Construct message from context kwargs."""
         return "Conflicting text attributes"
 
@@ -197,7 +197,7 @@ class ShadowstepConflictingDescriptionAttributesError(ShadowstepValidationError)
 
     default_message = "ShadowstepConflictingDescriptionAttributesError occurred"
 
-    def _construct_message_from_context(self, **context_kwargs: Any) -> str:
+    def _construct_message_from_context(self, **context_kwargs: Any) -> str:  # noqa: ARG002
         """Construct message from context kwargs."""
         return "Conflicting description attributes"
 
@@ -209,7 +209,7 @@ class ShadowstepHierarchicalAttributeError(ShadowstepValidationError):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        key = context_kwargs.get('key', 'attribute')
+        key = context_kwargs.get("key", "attribute")
         return f"Hierarchical attribute {key} must have dict value"
 
 
@@ -220,7 +220,7 @@ class ShadowstepUnsupportedSelectorFormatError(ShadowstepConversionError):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        selector = context_kwargs.get('selector', 'unknown')
+        selector = context_kwargs.get("selector", "unknown")
         return f"Unsupported selector format: {selector}"
 
 
@@ -231,9 +231,9 @@ class ShadowstepConversionFailedError(ShadowstepConversionError):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        function_name = context_kwargs.get('function_name', 'Unknown')
-        selector = context_kwargs.get('selector', 'unknown')
-        details = context_kwargs.get('details', 'unknown error')
+        function_name = context_kwargs.get("function_name", "Unknown")
+        selector = context_kwargs.get("selector", "unknown")
+        details = context_kwargs.get("details", "unknown error")
         return f"{function_name} failed to convert selector: {selector}. {details}"
 
 
@@ -244,7 +244,7 @@ class ShadowstepUnsupportedTupleFormatError(ShadowstepValidationError):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        format_type = context_kwargs.get('format_type', 'unknown')
+        format_type = context_kwargs.get("format_type", "unknown")
         return f"Unsupported tuple format: {format_type}"
 
 
@@ -253,7 +253,7 @@ class ShadowstepEmptyXPathError(ShadowstepValidationError):
 
     default_message = "ShadowstepEmptyXPathError occurred"
 
-    def _construct_message_from_context(self, **context_kwargs: Any) -> str:
+    def _construct_message_from_context(self, **context_kwargs: Any) -> str:  # noqa: ARG002
         """Construct message from context kwargs."""
         return "XPath string cannot be empty"
 
@@ -263,7 +263,7 @@ class ShadowstepEmptySelectorStringError(ShadowstepValidationError):
 
     default_message = "ShadowstepEmptySelectorStringError occurred"
 
-    def _construct_message_from_context(self, **context_kwargs: Any) -> str:
+    def _construct_message_from_context(self, **context_kwargs: Any) -> str:  # noqa: ARG002
         """Construct message from context kwargs."""
         return "Selector string cannot be empty"
 
@@ -275,7 +275,7 @@ class ShadowstepUnsupportedSelectorTypeError(ShadowstepValidationError):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        selector_type = context_kwargs.get('selector_type', 'unknown')
+        selector_type = context_kwargs.get("selector_type", "unknown")
         return f"Unsupported selector type: {selector_type}"
 
 
@@ -286,8 +286,8 @@ class ShadowstepUiSelectorConversionError(ShadowstepConversionError):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        operation = context_kwargs.get('operation', 'conversion')
-        details = context_kwargs.get('details', 'unknown error')
+        operation = context_kwargs.get("operation", "conversion")
+        details = context_kwargs.get("details", "unknown error")
         return f"Failed to convert UiSelector to {operation}: {details}"
 
 
@@ -298,7 +298,7 @@ class ShadowstepInvalidUiSelectorStringError(ShadowstepInvalidUiSelectorError):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        details = context_kwargs.get('details', 'unknown error')
+        details = context_kwargs.get("details", "unknown error")
         return f"Invalid UiSelector string: {details}"
 
 
@@ -309,7 +309,7 @@ class ShadowstepSelectorToXPathError(ShadowstepConversionError):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        details = context_kwargs.get('details', 'unknown error')
+        details = context_kwargs.get("details", "unknown error")
         return f"Failed to convert selector to XPath: {details}"
 
 
@@ -320,7 +320,7 @@ class ShadowstepMethodRequiresArgumentError(ShadowstepValidationError):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        method_name = context_kwargs.get('method_name', 'method')
+        method_name = context_kwargs.get("method_name", "method")
         return f"Method '{method_name}' requires an argument"
 
 
@@ -329,7 +329,7 @@ class ShadowstepConflictingMethodsError(ShadowstepValidationError):
 
     default_message = "ShadowstepConflictingMethodsError occurred"
 
-    def _construct_message_from_context(self, **context_kwargs: Any) -> str:
+    def _construct_message_from_context(self, **context_kwargs: Any) -> str:  # noqa: ARG002
         """Construct message from context kwargs."""
         return "Conflicting methods"
 
@@ -341,7 +341,7 @@ class ShadowstepUnsupportedNestedSelectorError(ShadowstepConversionError):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        selector_type = context_kwargs.get('selector_type', 'unknown')
+        selector_type = context_kwargs.get("selector_type", "unknown")
         return f"Unsupported nested selector type: {selector_type}"
 
 
@@ -352,7 +352,7 @@ class ShadowstepUiSelectorMethodArgumentError(ShadowstepConversionError):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        arg_count = context_kwargs.get('arg_count', 0)
+        arg_count = context_kwargs.get("arg_count", 0)
         return f"UiSelector methods typically take 0-1 arguments, got {arg_count}"
 
 
@@ -363,8 +363,7 @@ class ShadowstepLexerError(ShadowstepConversionError):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        message = context_kwargs.get('message', 'lexical error')
-        return message
+        return context_kwargs.get("message", "lexical error")
 
 
 class ShadowstepUnterminatedStringError(ShadowstepLexerError):
@@ -374,7 +373,7 @@ class ShadowstepUnterminatedStringError(ShadowstepLexerError):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        position = context_kwargs.get('position', 0)
+        position = context_kwargs.get("position", 0)
         return f"Unterminated string at {position}"
 
 
@@ -385,7 +384,7 @@ class ShadowstepBadEscapeError(ShadowstepLexerError):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        position = context_kwargs.get('position', 0)
+        position = context_kwargs.get("position", 0)
         return f"Bad escape at {position}"
 
 
@@ -396,8 +395,8 @@ class ShadowstepUnexpectedCharError(ShadowstepLexerError):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        char = context_kwargs.get('char', '?')
-        position = context_kwargs.get('position', 0)
+        char = context_kwargs.get("char", "?")
+        position = context_kwargs.get("position", 0)
         return f"Unexpected char '{char}' at {position}"
 
 
@@ -408,8 +407,7 @@ class ShadowstepParserError(ShadowstepException):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        message = context_kwargs.get('message', 'parse error')
-        return message
+        return context_kwargs.get("message", "parse error")
 
 
 class ShadowstepExpectedTokenError(ShadowstepParserError):
@@ -419,9 +417,9 @@ class ShadowstepExpectedTokenError(ShadowstepParserError):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        expected = context_kwargs.get('expected', 'TOKEN')
-        got = context_kwargs.get('got', 'UNKNOWN')
-        position = context_kwargs.get('position', 0)
+        expected = context_kwargs.get("expected", "TOKEN")
+        got = context_kwargs.get("got", "UNKNOWN")
+        position = context_kwargs.get("position", 0)
         return f"Expected {expected}, got {got} at {position}"
 
 
@@ -432,8 +430,8 @@ class ShadowstepUnexpectedTokenError(ShadowstepParserError):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        token_type = context_kwargs.get('token_type', 'UNKNOWN')
-        position = context_kwargs.get('position', 0)
+        token_type = context_kwargs.get("token_type", "UNKNOWN")
+        position = context_kwargs.get("position", 0)
         return f"Unexpected token in arg: {token_type} at {position}"
 
 
@@ -444,8 +442,7 @@ class ShadowstepXPathConversionError(ShadowstepConversionError):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        message = context_kwargs.get('message', 'xpath error')
-        return message
+        return context_kwargs.get("message", "xpath error")
 
 
 class ShadowstepBooleanLiteralError(ShadowstepXPathConversionError):
@@ -455,7 +452,7 @@ class ShadowstepBooleanLiteralError(ShadowstepXPathConversionError):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        value = context_kwargs.get('value', 'unknown')
+        value = context_kwargs.get("value", "unknown")
         return f"Expected boolean literal, got: '{value}'"
 
 
@@ -466,7 +463,7 @@ class ShadowstepNumericLiteralError(ShadowstepXPathConversionError):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        value = context_kwargs.get('value', 'unknown')
+        value = context_kwargs.get("value", "unknown")
         return f"Expected numeric literal, got: '{value}'"
 
 
@@ -475,7 +472,7 @@ class ShadowstepLogicalOperatorsNotSupportedError(ShadowstepXPathConversionError
 
     default_message = "ShadowstepLogicalOperatorsNotSupportedError occurred"
 
-    def _construct_message_from_context(self, **context_kwargs: Any) -> str:
+    def _construct_message_from_context(self, **context_kwargs: Any) -> str:  # noqa: ARG002
         """Construct message from context kwargs."""
         return "Logical operators (and/or) are not supported"
 
@@ -487,7 +484,7 @@ class ShadowstepInvalidXPathError(ShadowstepXPathConversionError):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        details = context_kwargs.get('details', 'unknown error')
+        details = context_kwargs.get("details", "unknown error")
         return f"Invalid XPath: {details}"
 
 
@@ -498,7 +495,7 @@ class ShadowstepUnsupportedAbbreviatedStepError(ShadowstepXPathConversionError):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        step = context_kwargs.get('step', 'unknown')
+        step = context_kwargs.get("step", "unknown")
         return f"Unsupported abbreviated step in UiSelector: '{step}'"
 
 
@@ -509,7 +506,7 @@ class ShadowstepUnsupportedASTNodeError(ShadowstepXPathConversionError):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        node = context_kwargs.get('node', {})
+        node = context_kwargs.get("node", {})
         return f"Unsupported AST node in UiSelector: {node}"
 
 
@@ -520,7 +517,7 @@ class ShadowstepUnsupportedASTNodeBuildError(ShadowstepXPathConversionError):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        node = context_kwargs.get('node', 'unknown')
+        node = context_kwargs.get("node", "unknown")
         return f"Unsupported AST node in build: '{node}'"
 
 
@@ -531,7 +528,7 @@ class ShadowstepContainsNotSupportedError(ShadowstepXPathConversionError):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        attr = context_kwargs.get('attr', 'attribute')
+        attr = context_kwargs.get("attr", "attribute")
         return f"contains() is not supported for @{attr}"
 
 
@@ -542,7 +539,7 @@ class ShadowstepStartsWithNotSupportedError(ShadowstepXPathConversionError):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        attr = context_kwargs.get('attr', 'attribute')
+        attr = context_kwargs.get("attr", "attribute")
         return f"starts-with() is not supported for @{attr}"
 
 
@@ -553,7 +550,7 @@ class ShadowstepMatchesNotSupportedError(ShadowstepXPathConversionError):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        attr = context_kwargs.get('attr', 'attribute')
+        attr = context_kwargs.get("attr", "attribute")
         return f"matches() is not supported for @{attr}"
 
 
@@ -564,7 +561,7 @@ class ShadowstepUnsupportedFunctionError(ShadowstepXPathConversionError):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        func_name = context_kwargs.get('func_name', 'unknown')
+        func_name = context_kwargs.get("func_name", "unknown")
         return f"Unsupported function: {func_name}"
 
 
@@ -575,7 +572,7 @@ class ShadowstepUnsupportedComparisonOperatorError(ShadowstepXPathConversionErro
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        operator = context_kwargs.get('operator', 'unknown')
+        operator = context_kwargs.get("operator", "unknown")
         return f"Unsupported comparison operator: {operator}"
 
 
@@ -586,7 +583,7 @@ class ShadowstepUnsupportedAttributeError(ShadowstepXPathConversionError):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        attr = context_kwargs.get('attr', 'unknown')
+        attr = context_kwargs.get("attr", "unknown")
         return f"Unsupported attribute: @{attr}"
 
 
@@ -597,7 +594,7 @@ class ShadowstepAttributePresenceNotSupportedError(ShadowstepXPathConversionErro
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        attr = context_kwargs.get('attr', 'unknown')
+        attr = context_kwargs.get("attr", "unknown")
         return f"Attribute presence predicate not supported for @{attr}"
 
 
@@ -608,7 +605,7 @@ class ShadowstepUnsupportedPredicateError(ShadowstepXPathConversionError):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        predicate = context_kwargs.get('predicate', 'unknown')
+        predicate = context_kwargs.get("predicate", "unknown")
         return f"Unsupported predicate: '{predicate}'"
 
 
@@ -619,7 +616,7 @@ class ShadowstepUnsupportedAttributeExpressionError(ShadowstepXPathConversionErr
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        node = context_kwargs.get('node', 'unknown')
+        node = context_kwargs.get("node", "unknown")
         return f"Unsupported attribute expression: '{node}'"
 
 
@@ -630,7 +627,7 @@ class ShadowstepUnsupportedLiteralError(ShadowstepXPathConversionError):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        node = context_kwargs.get('node', 'unknown')
+        node = context_kwargs.get("node", "unknown")
         return f"Unsupported literal: '{node}'"
 
 
@@ -641,7 +638,7 @@ class ShadowstepUnbalancedUiSelectorError(ShadowstepXPathConversionError):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        selector = context_kwargs.get('selector', 'unknown')
+        selector = context_kwargs.get("selector", "unknown")
         return f"Unbalanced UiSelector string: too many '(' in {selector}"
 
 
@@ -650,7 +647,7 @@ class ShadowstepEqualityComparisonError(ShadowstepXPathConversionError):
 
     default_message = "ShadowstepEqualityComparisonError occurred"
 
-    def _construct_message_from_context(self, **context_kwargs: Any) -> str:
+    def _construct_message_from_context(self, **context_kwargs: Any) -> str:  # noqa: ARG002
         """Construct message from context kwargs."""
         return "Equality must compare @attribute or text() with a literal"
 
@@ -662,8 +659,8 @@ class ShadowstepFunctionArgumentCountError(ShadowstepXPathConversionError):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        func_name = context_kwargs.get('func_name', 'function')
-        arg_count = context_kwargs.get('arg_count', 0)
+        func_name = context_kwargs.get("func_name", "function")
+        arg_count = context_kwargs.get("arg_count", 0)
         return f"{func_name}() must have {arg_count} arguments"
 
 
@@ -674,7 +671,7 @@ class ShadowstepUnsupportedAttributeForUiSelectorError(ShadowstepValidationError
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        attr = context_kwargs.get('attr', 'unknown')
+        attr = context_kwargs.get("attr", "unknown")
         return f"Unsupported attribute for UiSelector conversion: {attr}"
 
 
@@ -685,7 +682,7 @@ class ShadowstepUnsupportedHierarchicalAttributeError(ShadowstepValidationError)
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        attr = context_kwargs.get('attr', 'unknown')
+        attr = context_kwargs.get("attr", "unknown")
         return f"Unsupported hierarchical attribute: {attr}"
 
 
@@ -696,7 +693,7 @@ class ShadowstepUnsupportedAttributeForXPathError(ShadowstepValidationError):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        attr = context_kwargs.get('attr', 'unknown')
+        attr = context_kwargs.get("attr", "unknown")
         return f"Unsupported attribute for XPath conversion: {attr}"
 
 
@@ -707,7 +704,7 @@ class ShadowstepUnsupportedUiSelectorMethodError(ShadowstepValidationError):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        method = context_kwargs.get('method', 'unknown')
+        method = context_kwargs.get("method", "unknown")
         return f"Unsupported UiSelector method: {method}"
 
 
@@ -718,7 +715,7 @@ class ShadowstepUnsupportedXPathAttributeError(ShadowstepValidationError):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        method = context_kwargs.get('method', 'unknown')
+        method = context_kwargs.get("method", "unknown")
         return f"Unsupported XPath attribute: {method}"
 
 
@@ -727,7 +724,7 @@ class ShadowstepInvalidUiSelectorStringFormatError(ShadowstepValidationError):
 
     default_message = "ShadowstepInvalidUiSelectorStringFormatError occurred"
 
-    def _construct_message_from_context(self, **context_kwargs: Any) -> str:
+    def _construct_message_from_context(self, **context_kwargs: Any) -> str:  # noqa: ARG002
         """Construct message from context kwargs."""
         return "Invalid UiSelector string format"
 
@@ -739,8 +736,7 @@ class ShadowstepLogcatError(ShadowstepException):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        message = context_kwargs.get('message', 'logcat error')
-        return message
+        return context_kwargs.get("message", "logcat error")
 
 
 class ShadowstepPollIntervalError(ShadowstepLogcatError):
@@ -748,7 +744,7 @@ class ShadowstepPollIntervalError(ShadowstepLogcatError):
 
     default_message = "ShadowstepPollIntervalError occurred"
 
-    def _construct_message_from_context(self, **context_kwargs: Any) -> str:
+    def _construct_message_from_context(self, **context_kwargs: Any) -> str:  # noqa: ARG002
         """Construct message from context kwargs."""
         return "poll_interval must be non-negative"
 
@@ -758,7 +754,7 @@ class ShadowstepEmptyFilenameError(ShadowstepLogcatError):
 
     default_message = "ShadowstepEmptyFilenameError occurred"
 
-    def _construct_message_from_context(self, **context_kwargs: Any) -> str:
+    def _construct_message_from_context(self, **context_kwargs: Any) -> str:  # noqa: ARG002
         """Construct message from context kwargs."""
         return "filename cannot be empty"
 
@@ -768,7 +764,7 @@ class ShadowstepLogcatConnectionError(ShadowstepLogcatError):
 
     default_message = "ShadowstepLogcatConnectionError occurred"
 
-    def _construct_message_from_context(self, **context_kwargs: Any) -> str:
+    def _construct_message_from_context(self, **context_kwargs: Any) -> str:  # noqa: ARG002
         """Construct message from context kwargs."""
         return "Cannot connect to any logcat WS endpoint"
 
@@ -780,8 +776,7 @@ class ShadowstepNavigatorError(ShadowstepException):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        message = context_kwargs.get('message', 'navigation error')
-        return message
+        return context_kwargs.get("message", "navigation error")
 
 
 class ShadowstepPageCannotBeNoneError(ShadowstepNavigatorError):
@@ -789,7 +784,7 @@ class ShadowstepPageCannotBeNoneError(ShadowstepNavigatorError):
 
     default_message = "ShadowstepPageCannotBeNoneError occurred"
 
-    def _construct_message_from_context(self, **context_kwargs: Any) -> str:
+    def _construct_message_from_context(self, **context_kwargs: Any) -> str:  # noqa: ARG002
         """Construct message from context kwargs."""
         return "page cannot be None"
 
@@ -799,7 +794,7 @@ class ShadowstepFromPageCannotBeNoneError(ShadowstepNavigatorError):
 
     default_message = "ShadowstepFromPageCannotBeNoneError occurred"
 
-    def _construct_message_from_context(self, **context_kwargs: Any) -> str:
+    def _construct_message_from_context(self, **context_kwargs: Any) -> str:  # noqa: ARG002
         """Construct message from context kwargs."""
         return "from_page cannot be None"
 
@@ -809,7 +804,7 @@ class ShadowstepToPageCannotBeNoneError(ShadowstepNavigatorError):
 
     default_message = "ShadowstepToPageCannotBeNoneError occurred"
 
-    def _construct_message_from_context(self, **context_kwargs: Any) -> str:
+    def _construct_message_from_context(self, **context_kwargs: Any) -> str:  # noqa: ARG002
         """Construct message from context kwargs."""
         return "to_page cannot be None"
 
@@ -819,7 +814,7 @@ class ShadowstepTimeoutMustBeNonNegativeError(ShadowstepNavigatorError):
 
     default_message = "ShadowstepTimeoutMustBeNonNegativeError occurred"
 
-    def _construct_message_from_context(self, **context_kwargs: Any) -> str:
+    def _construct_message_from_context(self, **context_kwargs: Any) -> str:  # noqa: ARG002
         """Construct message from context kwargs."""
         return "timeout must be non-negative"
 
@@ -829,7 +824,7 @@ class ShadowstepPathCannotBeEmptyError(ShadowstepNavigatorError):
 
     default_message = "ShadowstepPathCannotBeEmptyError occurred"
 
-    def _construct_message_from_context(self, **context_kwargs: Any) -> str:
+    def _construct_message_from_context(self, **context_kwargs: Any) -> str:  # noqa: ARG002
         """Construct message from context kwargs."""
         return "path cannot be empty"
 
@@ -839,7 +834,7 @@ class ShadowstepPathMustContainAtLeastTwoPagesError(ShadowstepNavigatorError):
 
     default_message = "ShadowstepPathMustContainAtLeastTwoPagesError occurred"
 
-    def _construct_message_from_context(self, **context_kwargs: Any) -> str:
+    def _construct_message_from_context(self, **context_kwargs: Any) -> str:  # noqa: ARG002
         """Construct message from context kwargs."""
         return "path must contain at least 2 pages for dom"
 
@@ -851,9 +846,9 @@ class ShadowstepNavigationFailedError(ShadowstepNavigatorError):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        from_page = context_kwargs.get('from_page', 'unknown')
-        to_page = context_kwargs.get('to_page', 'unknown')
-        method = context_kwargs.get('method', 'unknown')
+        from_page = context_kwargs.get("from_page", "unknown")
+        to_page = context_kwargs.get("to_page", "unknown")
+        method = context_kwargs.get("method", "unknown")
         return f"Navigation error: failed to navigate from {from_page} to {to_page} using method {method}"
 
 
@@ -864,8 +859,7 @@ class ShadowstepPageObjectError(ShadowstepException):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        message = context_kwargs.get('message', 'page object error')
-        return message
+        return context_kwargs.get("message", "page object error")
 
 
 class ShadowstepUnsupportedRendererTypeError(ShadowstepPageObjectError):
@@ -875,7 +869,7 @@ class ShadowstepUnsupportedRendererTypeError(ShadowstepPageObjectError):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        renderer_type = context_kwargs.get('renderer_type', 'unknown')
+        renderer_type = context_kwargs.get("renderer_type", "unknown")
         return f"Unsupported renderer type: {renderer_type}"
 
 
@@ -884,7 +878,7 @@ class ShadowstepTitleNotFoundError(ShadowstepPageObjectError):
 
     default_message = "ShadowstepTitleNotFoundError occurred"
 
-    def _construct_message_from_context(self, **context_kwargs: Any) -> str:
+    def _construct_message_from_context(self, **context_kwargs: Any) -> str:  # noqa: ARG002
         """Construct message from context kwargs."""
         return "Can't find title"
 
@@ -894,7 +888,7 @@ class ShadowstepNameCannotBeEmptyError(ShadowstepPageObjectError):
 
     default_message = "ShadowstepNameCannotBeEmptyError occurred"
 
-    def _construct_message_from_context(self, **context_kwargs: Any) -> str:
+    def _construct_message_from_context(self, **context_kwargs: Any) -> str:  # noqa: ARG002
         """Construct message from context kwargs."""
         return "Name cannot be empty"
 
@@ -904,7 +898,7 @@ class ShadowstepPageClassNameCannotBeEmptyError(ShadowstepPageObjectError):
 
     default_message = "ShadowstepPageClassNameCannotBeEmptyError occurred"
 
-    def _construct_message_from_context(self, **context_kwargs: Any) -> str:
+    def _construct_message_from_context(self, **context_kwargs: Any) -> str:  # noqa: ARG002
         """Construct message from context kwargs."""
         return "page_class_name cannot be empty"
 
@@ -914,7 +908,7 @@ class ShadowstepTitleNodeNoUsableNameError(ShadowstepPageObjectError):
 
     default_message = "ShadowstepTitleNodeNoUsableNameError occurred"
 
-    def _construct_message_from_context(self, **context_kwargs: Any) -> str:
+    def _construct_message_from_context(self, **context_kwargs: Any) -> str:  # noqa: ARG002
         """Construct message from context kwargs."""
         return "Title node does not contain usable name"
 
@@ -926,7 +920,7 @@ class ShadowstepFailedToNormalizeScreenNameError(ShadowstepPageObjectError):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        text = context_kwargs.get('text', 'unknown')
+        text = context_kwargs.get("text", "unknown")
         return f"Failed to normalize screen name from '{text}'"
 
 
@@ -935,7 +929,7 @@ class ShadowstepNoClassDefinitionFoundError(ShadowstepPageObjectError):
 
     default_message = "ShadowstepNoClassDefinitionFoundError occurred"
 
-    def _construct_message_from_context(self, **context_kwargs: Any) -> str:
+    def _construct_message_from_context(self, **context_kwargs: Any) -> str:  # noqa: ARG002
         """Construct message from context kwargs."""
         return "No class definition found in the given source."
 
@@ -945,7 +939,7 @@ class ShadowstepRootNodeFilteredOutError(ShadowstepPageObjectError):
 
     default_message = "ShadowstepRootNodeFilteredOutError occurred"
 
-    def _construct_message_from_context(self, **context_kwargs: Any) -> str:
+    def _construct_message_from_context(self, **context_kwargs: Any) -> str:  # noqa: ARG002
         """Construct message from context kwargs."""
         return "Root node was filtered out and has no valid children."
 
@@ -955,7 +949,7 @@ class ShadowstepTerminalNotInitializedError(ShadowstepPageObjectError):
 
     default_message = "ShadowstepTerminalNotInitializedError occurred"
 
-    def _construct_message_from_context(self, **context_kwargs: Any) -> str:
+    def _construct_message_from_context(self, **context_kwargs: Any) -> str:  # noqa: ARG002
         """Construct message from context kwargs."""
         return "Terminal is not initialized"
 
@@ -965,7 +959,7 @@ class ShadowstepNoClassDefinitionFoundInTreeError(ShadowstepPageObjectError):
 
     default_message = "ShadowstepNoClassDefinitionFoundInTreeError occurred"
 
-    def _construct_message_from_context(self, **context_kwargs: Any) -> str:
+    def _construct_message_from_context(self, **context_kwargs: Any) -> str:  # noqa: ARG002
         """Construct message from context kwargs."""
         return "No class definition found"
 
@@ -977,8 +971,7 @@ class ShadowstepTranslatorError(ShadowstepException):
 
     def _construct_message_from_context(self, **context_kwargs: Any) -> str:
         """Construct message from context kwargs."""
-        message = context_kwargs.get('message', 'translation error')
-        return message
+        return context_kwargs.get("message", "translation error")
 
 
 class ShadowstepMissingYandexTokenError(ShadowstepTranslatorError):
@@ -986,7 +979,7 @@ class ShadowstepMissingYandexTokenError(ShadowstepTranslatorError):
 
     default_message = "ShadowstepMissingYandexTokenError occurred"
 
-    def _construct_message_from_context(self, **context_kwargs: Any) -> str:
+    def _construct_message_from_context(self, **context_kwargs: Any) -> str:  # noqa: ARG002
         """Construct message from context kwargs."""
         return "Missing yandexPassportOauthToken environment variable"
 
@@ -996,6 +989,6 @@ class ShadowstepTranslationFailedError(ShadowstepTranslatorError):
 
     default_message = "ShadowstepTranslationFailedError occurred"
 
-    def _construct_message_from_context(self, **context_kwargs: Any) -> str:
+    def _construct_message_from_context(self, **context_kwargs: Any) -> str:  # noqa: ARG002
         """Construct message from context kwargs."""
         return "Translation failed: empty response"
